Constant class
Constructors
- Constant()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- baseURL → const String
- checkInvoiceStatus → const String
- checkPaymentLinkStatus → const String
- checkPaymentStatus → const String
- createPayment → const String
- createPaymentMethod → const String
- createPaymentSession → const String
- createPlan → const String
- createSubscription → const String
- getAccount → const String
- getCard → const String
- getCustomer → const String
- getProfile → const String
- getSetupSession → const String
- getSubscription → const String
- paymentLink → const String
- paymentURL → const String
- testBaseURL → const String
- webLink → const String