Customer class

Constructors

Customer({dynamic gid, dynamic email, dynamic name, dynamic phoneNumber, dynamic taxId, dynamic taxStatus, dynamic taxValue})
Customer.fromJson(Map<String, dynamic> json)

Properties

billingAddress SPBillingAddress?
getter/setter pair
email String?
getter/setter pair
error String?
getter/setter pair
gid String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress SPShippingAddress?
getter/setter pair
taxId String?
getter/setter pair
taxStatus String?
getter/setter pair
taxValue String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toMapCreateCustomer() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited