OrderInfo class

Constructors

OrderInfo(String? receiptEmail, String? receiptSms, String? currencyCode, String? description, String? statementDescriptor, int? amount, {List<String>? paymentMethodType, String? paymentMethodGid})
OrderInfo.fromJson(Map<String, dynamic> json)

Properties

amount int?
getter/setter pair
captureMethod String
getter/setter pair
confirmMethod String
getter/setter pair
currencyCode String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paymentMethodGid String?
getter/setter pair
paymentMethodType List<String>?
getter/setter pair
receiptEmail String?
getter/setter pair
receiptSms String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statementDescriptor String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited