PaymentSession class

Constructors

PaymentSession()
PaymentSession.fromJson(Map<String, dynamic> json)

Properties

error String?
getter/setter pair
errorDescription String?
getter/setter pair
gid String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextActionUrl String?
getter/setter pair
psClientSecret String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited