Plan class

Constructors

Plan(String? name, int? amount, String? description, String? currencyCode, String? billingFrequency, int? billingPeriod, {String? gid, Currency? currency, String? planStartDate, List<String>? taxRateList, String? couponId, int? quantity, int? totalCount, String? status})
Plan.fromJson(Map<String, dynamic> json)

Properties

amount int?
getter/setter pair
billingFrequency String?
getter/setter pair
billingPeriod int?
getter/setter pair
couponId String?
getter/setter pair
currency Currency?
getter/setter pair
currencyCode String?
getter/setter pair
description String?
getter/setter pair
gid String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
planStartDate String?
getter/setter pair
quantity int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair
taxRateList List<String>?
getter/setter pair
totalCount int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited