RestAdapter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCustomer(
Customer customer) → Future< Customer> -
createPaymentButtonRequest(
PaymentRequest paymentRequest) → Future< Response> -
createPaymentMethod(
PaymentMethodCard paymentMethodCard) → Future< SuccessResponse> -
createPaymentMethodNetbanking(
PaymentMethodNetBanking paymentMethodNetBanking) → Future< SuccessResponse> -
createPaymentMethodUpi(
PaymentMethodUpi paymentMethodUpi) → Future< SuccessResponse> -
createPaymentsession(
OrderInfo orderInfo, {String? bankName}) → Future< PaymentSession> -
createPlan(
Plan planRequest, String key) → Future< Response> -
createSubscription(
SubscriptionRequest subscriptionRequest, String key) → Future< Response> -
fetchPaymentLink(
PaymentRequest paymentRequest) → Future< Response> -
fetchPaymentSession(
String? gid, String? secret) → Future< SuccessResponse> -
fetchSubscriptionButton(
String subscriptionGid) → Future< SuccessResponse> -
getAccount(
String? accountGid) → Future< SuccessResponse> -
getCustomer(
String? name, String? email, String? phoneNumber) → Future< SuccessResponse> -
getProfile(
) → Future< Profile> -
getSavedCards(
String customerGid) → Future< List< SavedCardResponse> > -
getSetupSession(
String setupSessionId) → Future< SuccessResponse> -
invoiceStatus(
String invoiceGid) → Future< SuccessResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paymentLinkStatus(
String paymentLinkGid) → Future< SuccessResponse> -
paymentStatus(
String paymentGid) → Future< SuccessResponse> -
toString(
) → String -
A string representation of this object.
inherited
-
updateCVV(
CardInfo cardInfo, String gid) → Future< SuccessResponse>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited