PaymentRequest class
Constructors
Properties
- amount ↔ String
-
getter/setter pair
- currencyCode ↔ String
-
getter/setter pair
- customer ↔ Customer?
-
getter/setter pair
- customerGid ↔ String?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- expiresAt ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notificationType ↔ String
-
getter/setter pair
-
paymentMethodType
↔ List<
String> ? -
getter/setter pair
- redirectUri ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited