SubscriptionResponse class
Constructors
-
SubscriptionResponse.fromJson(Map<
String, dynamic> json)
Properties
- account ↔ Account?
-
getter/setter pair
- coupon ↔ Coupon?
-
getter/setter pair
- currency ↔ Currency?
-
getter/setter pair
- gid ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- link ↔ String?
-
getter/setter pair
- plan ↔ Plan?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
-
taxAmount
↔ List<
TaxInfo> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited